@@ -1,7 +1,7 @@
 /*
  *  alarmtimewidget.cpp  -  alarm date/time entry widget
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2001-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2021 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -83,7 +83,7 @@ void AlarmTimeWidget::init(Mode mode, const QString& title)
     mDeferring = mode & DEFER_TIME;
     mButtonGroup = new ButtonGroup(this);
     connect(mButtonGroup, &ButtonGroup::buttonSet, this, &AlarmTimeWidget::slotButtonSet);
-    auto* topLayout = new QVBoxLayout(topWidget);
+    auto topLayout = new QVBoxLayout(topWidget);
     if (title.isEmpty())
         topLayout->setContentsMargins(0, 0, 0, 0);
 
@@ -105,7 +105,7 @@ void AlarmTimeWidget::init(Mode mode, const QString& title)
 
     // Time edit box and Any time checkbox
     QWidget* timeBox = new QWidget(topWidget);
-    auto* timeBoxHLayout = new QHBoxLayout(timeBox);
+    auto timeBoxHLayout = new QHBoxLayout(timeBox);
     timeBoxHLayout->setContentsMargins(0, 0, 0, 0);
     timeBoxHLayout->setSpacing(2 * style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing));
     mTimeEdit = new TimeEdit(timeBox);
@@ -151,7 +151,7 @@ void AlarmTimeWidget::init(Mode mode, const QString& title)
     mAfterTimeRadio->setFocusWidget(mDelayTimeEdit);
 
     // Set up the layout, either narrow or wide
-    auto* grid = new QGridLayout();
+    auto grid = new QGridLayout();
     grid->setContentsMargins(0, 0, 0, 0);
     topLayout->addLayout(grid);
     if (mDeferring)
@@ -161,7 +161,7 @@ void AlarmTimeWidget::init(Mode mode, const QString& title)
         grid->addWidget(timeBox, 1, 1, Qt::AlignLeft);
         grid->setColumnStretch(2, 1);
         topLayout->addStretch();
-        auto* layout = new QHBoxLayout();
+        auto layout = new QHBoxLayout();
         topLayout->addLayout(layout);
         layout->addWidget(mAfterTimeRadio);
         layout->addWidget(mDelayTimeEdit);
@@ -186,13 +186,13 @@ void AlarmTimeWidget::init(Mode mode, const QString& title)
         grid->setColumnStretch(2, 1);
         topLayout->addStretch();
 
-        auto* layout = new QHBoxLayout();
+        auto layout = new QHBoxLayout();
         topLayout->addLayout(layout);
         layout->setSpacing(2 * style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing));
 
         // Time zone selector
         mTimeZoneBox = new QWidget(topWidget);   // this is to control the QWhatsThis text display area
-        auto* hlayout = new QHBoxLayout(mTimeZoneBox);
+        auto hlayout = new QHBoxLayout(mTimeZoneBox);
         hlayout->setContentsMargins(0, 0, 0, 0);
         QLabel* label = new QLabel(i18nc("@label:listbox", "Time zone:"), mTimeZoneBox);
         hlayout->addWidget(label);
@@ -234,13 +234,19 @@ void AlarmTimeWidget::setReadOnly(bool ro)
 }
 
 /******************************************************************************
-* Select the "Time from now" radio button.
+* Select the "Time from now" radio button, or if minutes < 0, select
+* 'At date/time'.
 */
 void AlarmTimeWidget::selectTimeFromNow(int minutes)
 {
-    mAfterTimeRadio->setChecked(true);
-    if (minutes > 0)
-        mDelayTimeEdit->setValue(minutes);
+    if (minutes >= 0)
+    {
+        mAfterTimeRadio->setChecked(true);
+        if (minutes > 0)
+            mDelayTimeEdit->setValue(minutes);
+    }
+    else
+        mAtTimeRadio->setChecked(true);
 }
 
 /******************************************************************************
