@@ -22,7 +22,6 @@
 #include <QDragEnterEvent>
 #include <QDropEvent>
 #include <QFocusEvent>
-#include <QDebug>
 
 
 /*=============================================================================
@@ -50,7 +49,7 @@ void LineEdit::init()
     if (mType == Url)
     {
         setCompletionMode(KCompletion::CompletionShell);
-        auto* comp = new KUrlCompletion(KUrlCompletion::FileCompletion);
+        auto comp = new KUrlCompletion(KUrlCompletion::FileCompletion);
         comp->setReplaceHome(true);
         setCompletionObject(comp);
         setAutoDeleteCompletionObject(true);
@@ -151,11 +150,7 @@ void LineEdit::dropEvent(QDropEvent* e)
         {
             // Remove newlines from a list of email addresses, and allow an eventual mailto: scheme
             const QString mailto = QStringLiteral("mailto:");
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-            newEmails = txt.split(QRegExp(QLatin1String("[\r\n]+")), QString::SkipEmptyParts);
-#else
             newEmails = txt.split(QRegExp(QLatin1String("[\r\n]+")), Qt::SkipEmptyParts);
-#endif
             for (QStringList::Iterator it = newEmails.begin();  it != newEmails.end();  ++it)
             {
                 if ((*it).startsWith(mailto))
