@@ -1,21 +1,9 @@
 /*
  *  timeedit.h  -  time-of-day edit widget, with AM/PM shown depending on locale
  *  Program:  kalarm
- *  Copyright © 2004-2019 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2004-2019 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef TIMEEDIT_H
@@ -73,7 +61,7 @@ class TimeEdit : public QWidget
         /** Returns the entered time as a value in minutes. */
         int           value() const;
         /** Returns the entered time as a QTime value. */
-        QTime         time() const                 { int m = value();  return QTime(m/60, m%60); }
+        QTime         time() const                 { int m = value();  return {m/60, m%60}; }
         /** Returns true if it is possible to step the value from the highest value to the lowest value and vice versa. */
         bool          wrapping() const;
         /** Sets whether it is possible to step the value from the highest value to the lowest value and vice versa.
@@ -85,7 +73,7 @@ class TimeEdit : public QWidget
         /** Returns the maximum value of the widget in minutes. */
         int           maximum() const;
         /** Returns the maximum value of the widget as a QTime value. */
-        QTime         maxTime() const              { int mv = maximum();  return QTime(mv/60, mv%60); }
+        QTime         maxTime() const              { int mv = maximum();  return {mv/60, mv%60}; }
         /** Sets the minimum value of the widget. */
         void          setMinimum(int minutes);
         /** Sets the maximum value of the widget. */
