@@ -1,7 +1,7 @@
 /*
  *  messagedisplayhelper.cpp  -  helper class to display an alarm or error message
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2001-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2021 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -812,7 +812,7 @@ void MessageDisplayHelper::playAudio()
     {
         // The message is to be spoken. In case of error messges,
         // call it on a timer to allow the display to be shown first.
-        QTimer::singleShot(0, this, &MessageDisplayHelper::slotSpeak);
+        QTimer::singleShot(0, this, &MessageDisplayHelper::slotSpeak);   //NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
     }
 }
 
@@ -895,7 +895,7 @@ void MessageDisplayHelper::playReady()
 */
 void MessageDisplayHelper::audioTerminating()
 {
-    QTimer::singleShot(0, this, &MessageDisplayHelper::startAudio);
+    QTimer::singleShot(0, this, &MessageDisplayHelper::startAudio);   //NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
 }
 
 /******************************************************************************
@@ -950,7 +950,7 @@ AudioThread::~AudioThread()
         mAudioOwner = nullptr;
     // Notify after deleting mAudioThread, so that isAudioPlaying() will
     // return the correct value.
-    QTimer::singleShot(0, theApp(), &KAlarmApp::notifyAudioStopped);
+    QTimer::singleShot(0, theApp(), &KAlarmApp::notifyAudioStopped);   //NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
 }
 
 /******************************************************************************
@@ -996,7 +996,7 @@ void AudioThread::run()
     mAudioObject = new Phonon::MediaObject();
     mAudioObject->setCurrentSource(source);
     mAudioObject->setTransitionTime(100);   // workaround to prevent clipping of end of files in Xine backend
-    auto* output = new Phonon::AudioOutput(Phonon::NotificationCategory, mAudioObject);
+    auto output = new Phonon::AudioOutput(Phonon::NotificationCategory, mAudioObject);   //NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
     mPath = Phonon::createPath(mAudioObject, output);
     if (mVolume >= 0  ||  mFadeVolume >= 0)
     {
@@ -1005,7 +1005,7 @@ void AudioThread::run()
         output->setVolume(maxvol);
         if (mFadeVolume >= 0  &&  mFadeSeconds > 0)
         {
-            auto* fader = new Phonon::VolumeFaderEffect(mAudioObject);
+            auto fader = new Phonon::VolumeFaderEffect(mAudioObject);
             fader->setVolume(mFadeVolume / maxvol);
             fader->fadeTo(mVolume / maxvol, mFadeSeconds * 1000);
             mPath.insertEffect(fader);
@@ -1059,7 +1059,7 @@ void AudioThread::checkAudioPlay()
             {
                 // Pause before playing the file again
                 mPausing = true;
-                QTimer::singleShot(mRepeatPause * 1000, this, &AudioThread::checkAudioPlay);
+                QTimer::singleShot(mRepeatPause * 1000, this, &AudioThread::checkAudioPlay);   //NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
                 mMutex.unlock();
                 return;
             }
@@ -1133,7 +1133,7 @@ bool MessageDisplayHelper::activateAutoClose()
         int delay = QDateTime::currentDateTimeUtc().secsTo(mCloseTime);
         if (delay < 0)
             delay = 0;
-        QTimer::singleShot(delay * 1000, this, &MessageDisplayHelper::autoCloseNow);
+        QTimer::singleShot(delay * 1000, this, &MessageDisplayHelper::autoCloseNow);   //NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
         if (!delay)
             return false;    // don't show the alarm if auto-closing is already due
     }
@@ -1187,7 +1187,7 @@ bool MessageDisplayHelper::closeEvent()
 EditAlarmDlg* MessageDisplayHelper::createEdit()
 {
     qCDebug(KALARM_LOG) << "MessageDisplayHelper::createEdit";
-    mEditDlg = EditAlarmDlg::create(false, &mOriginalEvent, false, MainWindow::mainMainWindow(), EditAlarmDlg::RES_IGNORE);
+    mEditDlg = EditAlarmDlg::create(false, mOriginalEvent, false, MainWindow::mainMainWindow(), EditAlarmDlg::RES_IGNORE);
     if (mEditDlg)
     {
         mEditDlg->setAttribute(Qt::WA_NativeWindow, true);
@@ -1261,7 +1261,7 @@ void MessageDisplayHelper::checkDeferralLimit()
         n = QDateTime::currentDateTimeUtc().secsTo(mDeferLimit);
         if (n > 0)
         {
-            QTimer::singleShot(n * 1000, this, &MessageDisplayHelper::checkDeferralLimit);
+            QTimer::singleShot(n * 1000, this, &MessageDisplayHelper::checkDeferralLimit);   //NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
             return;
         }
     }
